@@ -9,6 +9,7 @@ from mypy_boto3_builder.enums.service_module_name import ServiceModuleName
 from mypy_boto3_builder.structures.service_package import ServicePackage
 from mypy_boto3_builder.writers.utils import (
     blackify,
+    fix_pypi_headers,
     format_md,
     insert_md_toc,
     render_jinja2_template,
@@ -136,6 +137,7 @@ def write_service_package(
             content = blackify(content, file_path)
         if file_path.suffix == ".md":
             content = insert_md_toc(content)
+            content = fix_pypi_headers(content)
             content = format_md(content)
 
         if not file_path.exists() or file_path.read_text() != content:
